# Generated by Django 2.0.5 on 2018-05-15 11:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("user_subscriptions", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="subscription",
            name="periodicity",
            field=models.CharField(
                choices=[
                    ("yearly", "yearly"), ("monthly", "monthly"), ("weekly", "weekly")
                ],
                max_length=20,
                verbose_name="periodicity",
            ),
        )
    ]
