# Generated by Django 2.0.5 on 2018-05-15 12:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("user_payments", "0001_initial"),
        ("user_subscriptions", "0002_auto_20180515_1351"),
    ]

    operations = [
        migrations.AddField(
            model_name="subscriptionperiod",
            name="line_item",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="user_payments.LineItem",
                verbose_name="line item",
            ),
        )
    ]
