# Generated by Django 2.0.5 on 2018-05-17 12:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("user_subscriptions", "0003_subscriptionperiod_line_item")]

    operations = [
        migrations.RenameField(
            model_name="subscription", old_name="is_active", new_name="_is_active"
        ),
        migrations.AddField(
            model_name="subscription",
            name="_is_automatically_renewed",
            field=models.BooleanField(
                default=False, verbose_name="is automatically renewed"
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="subscription",
            name="ends_at",
            field=models.DateTimeField(blank=True, null=True, verbose_name="ends at"),
        ),
        migrations.AlterField(
            model_name="subscription",
            name="periodicity",
            field=models.CharField(
                choices=[
                    ("yearly", "yearly"),
                    ("monthly", "monthly"),
                    ("weekly", "weekly"),
                    ("manually", "manually"),
                ],
                max_length=20,
                verbose_name="periodicity",
            ),
        ),
        migrations.AlterField(
            model_name="subscription",
            name="starts_at",
            field=models.DateTimeField(verbose_name="starts at"),
        ),
    ]
