# Generated by Django 2.0.5 on 2018-05-17 07:32

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("user_subscriptions", "0005_auto_20180517_1441")]

    operations = [
        migrations.AlterField(
            model_name="subscription",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="user_subscriptions",
                to=settings.AUTH_USER_MODEL,
                verbose_name="user",
            ),
        ),
        migrations.AlterField(
            model_name="subscriptionperiod",
            name="line_item",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="user_payments.LineItem",
                verbose_name="line item",
            ),
        ),
    ]
