# Generated by Django 2.0.5 on 2018-05-17 12:41

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [("user_subscriptions", "0004_auto_20180517_1435")]

    operations = [
        migrations.RemoveField(model_name="subscription", name="_is_active"),
        migrations.RemoveField(
            model_name="subscription", name="_is_automatically_renewed"
        ),
        migrations.AddField(
            model_name="subscription",
            name="paid_until",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="paid until"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subscription",
            name="renew_automatically",
            field=models.BooleanField(
                default=False, verbose_name="renew automatically"
            ),
            preserve_default=False,
        ),
    ]
